@@ -5,7 +5,7 @@ import requests
 
 from .serialization import Deserializer
 from .utilities import get_auth
-from .converters import to_dataframe
+from .converters import to_dataframe, metrics_to_dataframe
 
 CONCURRENT_DOWNLOADS = 10
 DOWNLOAD_CHUNK_SIZE = 8192
@@ -258,3 +258,102 @@ class Client(object):
 
         else:
             raise Exception(response.text)
+
+    def get_folder(self, folder, tags=False, metadata=False):
+        """
+        Get a single folder
+        """
+        params = {'name': folder,
+                  'tags': tags,
+                  'metadata': metadata}
+
+        response = requests.get(f"{self._url}/api/folders", headers=self._headers, params=params)
+
+        if response.status_code == 404:
+            if 'detail' in response.json():
+                if response.json()['detail'] == 'no such folder':
+                    raise Exception('Folder does not exist')
+
+        if response.status_code == 200:
+            return response.json()
+
+        raise Exception(response.text)
+
+    def get_folders(self, filters, tags=False, metadata=False):
+        """
+        Get folders
+        """
+        params = {'filters': ','.join(filters),
+                  'tags': tags,
+                  'metadata': metadata}
+
+        response = requests.get(f"{self._url}/api/folders", headers=self._headers, params=params)
+
+        if response.status_code == 200:
+            return response.json()
+
+        raise Exception(response.text)
+
+    def get_metrics_summaries(self, run, name):
+        """
+        Get summary metrics for the specified run and metrics name
+        """
+        params = {'runs': run,
+                  'metrics': name,
+                  'summary': True}
+
+        response = requests.get(f"{self._url}/api/metrics", headers=self._headers, params=params)
+
+        if response.status_code == 200:
+            return response.json()
+
+        raise Exception(response.text)
+
+    def get_metrics(self, run, name, xaxis, format='list'):
+        """
+        Get time series metrics for the specified run and metrics name
+        """
+        params = {'runs': run,
+                  'metrics': name,
+                  'summary': False,
+                  'xaxis': xaxis}
+
+        if xaxis not in ('step', 'time', 'timestamp'):
+            raise Exception('Invalid xaxis specified, should be either "step", "time", or "timestamp"')
+
+        if format not in ('list', 'dataframe'):
+            raise Exception('Invalid format specified, should be either "list" or "dataframe"')
+
+        response = requests.get(f"{self._url}/api/metrics", headers=self._headers, params=params)
+
+        if response.status_code == 200:
+            if format == 'dataframe':
+                return metrics_to_dataframe(response.json(), xaxis, name=name)
+            return response.json()
+
+        raise Exception(response.text)
+
+    def get_metrics_multiple(self, runs, names, xaxis, sample_by, format='list'):
+        """
+        Get time series metrics from multiple runs and/or metrics
+        """
+        params = {'runs': ','.join(runs),
+                  'metrics': ','.join(names),
+                  'summary': False,
+                  'sample_by': sample_by,
+                  'xaxis': xaxis}
+
+        if xaxis not in ('step', 'time'):
+            raise Exception('Invalid xaxis specified, should be either "step" or "time"')
+
+        if format not in ('list', 'dataframe'):
+            raise Exception('Invalid format specified, should be either "list" or "dataframe"')
+
+        response = requests.get(f"{self._url}/api/metrics", headers=self._headers, params=params)
+
+        if response.status_code == 200:
+            if format == 'dataframe':
+                return metrics_to_dataframe(response.json(), xaxis)
+            return response.json()
+
+        raise Exception(response.text)
